@@ -409,7 +409,7 @@ def sanitize_anndata(adata):
 def view_to_actual(adata):
     if adata.is_view:
         warnings.warn(
-            "Revieved a view of an AnnData. Making a copy.",
+            "Received a view of an AnnData. Making a copy.",
             stacklevel=2,
         )
         adata._init_as_actual(adata.copy())
