@@ -1,6 +1,7 @@
 from typing import Union, List, Optional, Any, Tuple, Collection
 
 import numpy as np
+import pandas as pd
 import matplotlib.pyplot as plt
 from anndata import AnnData
 from matplotlib.axes import Axes
@@ -340,6 +341,8 @@ def scrublet_score_distribution(
     The histogram for simulated doublets is useful for determining the correct doublet
     score threshold.
 
+    Scrublet must have been run previously with the input object.
+
     Parameters
     ----------
     adata
@@ -372,40 +375,84 @@ def scrublet_score_distribution(
         simulation separately for advanced usage.
     """
 
-    threshold = adata.uns['scrublet']['threshold']
-    fig, axs = plt.subplots(1, 2, figsize=figsize)
+    def _plot_scores(
+        ax: plt.Axes, scores: np.ndarray, scale: str, title: str, threshold=None
+    ):
+        ax.hist(
+            scores,
+            np.linspace(0, 1, 50),
+            color='gray',
+            linewidth=0,
+            density=True,
+        )
+        ax.set_yscale(scale)
+        yl = ax.get_ylim()
+        ax.set_ylim(yl)
 
-    ax = axs[0]
-    ax.hist(
-        adata.obs['doublet_score'],
-        np.linspace(0, 1, 50),
-        color='gray',
-        linewidth=0,
-        density=True,
-    )
-    ax.set_yscale(scale_hist_obs)
-    yl = ax.get_ylim()
-    ax.set_ylim(yl)
-    ax.plot(threshold * np.ones(2), yl, c='black', linewidth=1)
-    ax.set_title('Observed transcriptomes')
-    ax.set_xlabel('Doublet score')
-    ax.set_ylabel('Prob. density')
+        if threshold is not None:
+            ax.plot(threshold * np.ones(2), yl, c='black', linewidth=1)
 
-    ax = axs[1]
-    ax.hist(
-        adata.uns['scrublet']['doublet_scores_sim'],
-        np.linspace(0, 1, 50),
-        color='gray',
-        linewidth=0,
-        density=True,
-    )
-    ax.set_yscale(scale_hist_sim)
-    yl = ax.get_ylim()
-    ax.set_ylim(yl)
-    ax.plot(threshold * np.ones(2), yl, c='black', linewidth=1)
-    ax.set_title('Simulated doublets')
-    ax.set_xlabel('Doublet score')
-    ax.set_ylabel('Prob. density')
+        ax.set_title(title)
+        ax.set_xlabel('Doublet score')
+        ax.set_ylabel('Prob. density')
+
+    if 'scrublet' not in adata.uns:
+        raise ValueError(
+            'Please run scrublet before trying to generate the scrublet plot.'
+        )
+
+    # If batched_by is populated, then we know Scrublet was run over multiple batches
+
+    if 'batched_by' in adata.uns['scrublet']:
+        batched_by = adata.uns['scrublet']['batched_by']
+        batches = adata.obs[batched_by].astype("category", copy=False)
+        n_batches = len(batches.cat.categories)
+        figsize = (figsize[0], figsize[1] * n_batches)
+    else:
+        batches = pd.Series(
+            np.broadcast_to(0, adata.n_obs), dtype="category", index=adata.obs_names
+        )
+        n_batches = 1
+
+    fig, axs = plt.subplots(n_batches, 2, figsize=figsize)
+
+    for idx, (batch_key, sub_obs) in enumerate(adata.obs.groupby(batches)):
+
+        # We'll need multiple rows if Scrublet was run in multiple batches
+        if 'batched_by' in adata.uns['scrublet']:
+
+            threshold = adata.uns["scrublet"]['batches'][batch_key].get(
+                "threshold", None
+            )
+            doublet_scores_sim = adata.uns['scrublet']['batches'][batch_key][
+                'doublet_scores_sim'
+            ]
+            axis_lab_suffix = " (%s)" % batch_key
+            obs_ax = axs[idx][0]
+            sim_ax = axs[idx][1]
+
+        else:
+            threshold = adata.uns["scrublet"].get("threshold", None)
+            doublet_scores_sim = adata.uns['scrublet']['doublet_scores_sim']
+            axis_lab_suffix = ''
+            obs_ax = axs[0]
+            sim_ax = axs[1]
+
+        # Make the plots
+        _plot_scores(
+            obs_ax,
+            sub_obs["doublet_score"],
+            scale=scale_hist_obs,
+            title=f"Observed transcriptomes {axis_lab_suffix}",
+            threshold=threshold,
+        )
+        _plot_scores(
+            sim_ax,
+            doublet_scores_sim,
+            scale=scale_hist_sim,
+            title=f"Simulated doublets {axis_lab_suffix}",
+            threshold=threshold,
+        )
 
     fig.tight_layout()
 
