@@ -73,7 +73,7 @@ def sim(
 
     Examples
     --------
-    See this `use case <https://github.com/theislab/scanpy_usage/tree/master/170430_krumsiek11>`__
+    See this `use case <https://github.com/scverse/scanpy_usage/tree/master/170430_krumsiek11>`__
     """
     params = locals()
     if params_file:
